# Changelog All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/).

## [Unreleased]

## [2020.12.0]

### Added
- initial release
- previously released under the name "PyCMDS" via github, never packaged.

[Unreleased]: https://github.com/wright-group/yaqc-cmds/compare/2020.12.0...master
[2020.12.0]: https://github.com/wright-group/yaqc-cmds/releases/tag/2020.12.0
